@@ -56,7 +56,12 @@ def issues_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
     # Lol @ access back to Sphinx
     config = inliner.document.settings.env.app.config
     if issue_no not in ('-', '0'):
-        ref = config.releases_issue_uri % issue_no
+        if config.releases_issue_uri:
+            # TODO: deal with % vs .format()
+            ref = config.releases_issue_uri % issue_no
+        elif config.releases_github_path:
+            ref = "https://github.com/{0}/issues/{1}".format(
+                config.releases_github_path, issue_no)
         link = nodes.reference(rawtext, '#' + issue_no, refuri=ref, **options)
     else:
         link = None
@@ -92,10 +97,13 @@ def release_nodes(text, slug, date, config):
     # title and give it these HTML attributes during render time) so...fuckit.
     # We were already doing fully raw elements elsewhere anyway. And who cares
     # about a PDF of a changelog? :x
-    link = '<a class="reference external" href="{0}">{1}</a>'.format(
-        config.releases_release_uri % slug,
-        text,
-    )
+    if config.releases_release_uri:
+        # TODO: % vs .format()
+        uri = config.releases_release_uri % slug
+    elif config.releases_github_path:
+        uri = "https://github.com/{0}/tree/{1}".format(
+            config.releases_github_path, slug)
+    link = '<a class="reference external" href="{0}">{1}</a>'.format(uri, text)
     datespan = ''
     if date:
         datespan = ' <span style="font-size: 75%%;">{0}</span>'.format(date)
@@ -410,7 +418,7 @@ def generate_changelog(app, doctree):
     # This seems to be the cleanest way to tell what a not-fully-parsed
     # document's 'name' is. Also lol @ not fully implementing dict protocol.
     source = doctree[0]
-    if 'changelog' not in source.get('names', []):
+    if app.config.releases_document_name not in source.get('names', []):
         return
     # Second item inside main document is the 'modern' changelog bullet-list
     # object, whose children are the nodes we care about.
@@ -430,6 +438,12 @@ def setup(app):
     # E.g. 'https://github.com/fabric/fabric/tree/'
     app.add_config_value(name='releases_release_uri', default=None,
         rebuild='html')
+    # Convenience Github version of above
+    app.add_config_value(name='releases_github_path', default=None,
+        rebuild='html')
+    # Which document to use as the changelog
+    app.add_config_value(name='releases_document_name', default='changelog',
+        rebuild='html')
     # Debug output
     app.add_config_value(name='releases_debug', default=False, rebuild='html')
     # Register intermediate roles
